
import os 

main_image = os.path.dirname(os.path.abspath(__file__)) + "/thumbsup.png"
sparkle_image = os.path.dirname(os.path.abspath(__file__)) + "/sparkle.png"

def main():
	cwd = os.getcwd()
	os.chdir(os.path.dirname(os.path.abspath(__file__)) + "/proj/")
	# os.system('make clean')
	# os.system('make install')

	os.system("/usr/local/bin/imageleap -i %s -p %s" % (main_image, sparkle_image))




#!/usr/bin/env python
from setuptools import setup, find_packages, Extension

setup(name='greatjob',
      version='1.1',
      description='Congratulations',
      author='Celeen Rusk',
      author_email='celeenrusk@gmail.com',
      liscense="MIT",
      packages=find_packages(),
      package_data={
            '': ['imageleap', 'sparkle.png', 'thumbsup.png', 'proj/*']
      },
      entry_points={
      	'console_scripts': [
      		'greatjob=greatjob:main'
      	]
      }
     )